==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/compagnon/lang/compagnon_sk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/compagnon?lang_cible=sk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// C
	'c_accueil_bienvenue' => 'Vitajte, @nom@!',
	'c_accueil_configurer_site' => 'Nastaviť si stránku',
	'c_accueil_configurer_site_texte' => 'Jednou z prvých vecí, ktoré treba urobiť, je dať stránke názov. 
                 Momentálne má názov "@nom@". Názov stránky sa zobrazuje v hornej časti tejto stránky. 
                Kliknutím môžete zmeniť jej názov a tiež pridať logo a slogan.',
	'c_accueil_publication' => 'Publikujte!',
	'c_accueil_publication_texte' => 'Na publikovanie stránky musíte vytvoriť článok.
		Môžete to urobiť v menu "Upraviť stránku" kliknutím na "Rubriky".',
	'c_accueil_texte' => 'Práve ste sa dostali do súkromnej zóny SPIPu.',
	'c_accueil_texte_revenir' => '		Táto stránka uvádza najnovšiu redakčnú aktivitu na vašej stránke.
		Na túto stránku sa môžete kedykoľvek vrátiť kliknutím na ikonu domčeka 
                            na vrchu pod svojím menom.',
	'c_article_redaction' => 'Článok sa upravuje',
	'c_article_redaction_redacteur' => 'Článok sa upravuje',
	'c_article_redaction_redacteur_texte' => 'Na to, aby bol váš článok odoslaný administrátorom stránky a iným redaktorom,
		v ráme na boku zmeňte stav "upravuje sa" na "odoslaný na schválenie".',
	'c_article_redaction_texte' => 'Zmeňte stav spracovania článku, aby bol jeho text publikovaný na verejne prístupnej stránke. 
		V ráme na boku zmeňte stav "upravuje sa" na "publikovaný online".',
	'c_articles_creer' => 'Vytvoriť komentár k článku?',
	'c_articles_creer_texte' => 'Vytvoriť článok môžete na tejto stránke, iba ak
		na vašej stránke existuje aspoň jedna rubrika.
		Môžete ho vytvoriť pomocou menu "Upraviť", potom "Rubriky".',
	'c_job' => 'Čo treba urobiť…',
	'c_job_texte' => 'Na tejto stránke sú uvedené nabližšie úlohy údržby,
		ktoré SPIP musí vykonať. Tieto úlohy sa vykonávajú v pravidelných intervaloch
		alebo presne na spracovanie veľkých požiadaviek zásuvných modulov,
		ako odoslanie hromadných e-mailov.',
	'c_rubrique_publier' => 'Vytvorte článok',
	'c_rubrique_publier_texte' => 'Rubrika je publikovaná, keď
		sa v nej nachádza aspoň jeden publikovaný text. Napríklad publikovaný článok.
		Takže vytvorte článok. Môžete to urobiť na tejto stránke pod opisom svojej rubriky.',
	'c_rubriques_creer' => 'Vytvorte prvú rubriku!',
	'c_rubriques_creer_texte' => 'Rubriky tvoria základnú štruktúru stránky.
		V každej z nich môžete vytvárať články.
		Začnite vytvárať prvú rubriku.',

	// E
	'explication_activer_compagnon' => 'Asistent pridáva komentáre na niektoré stránky
			súkromnej zóny, aby vám pomohol s ovládaním SPIPu. Chcete ho aktivovať?',
	'explication_reinitialiser_compagnon' => 'Správy, ktoré autor videl, sa už viac nezobrazujú.			Chcete obnoviť tieto správy?',

	// L
	'label_activer_compagnon' => 'Aktivovať Sprievodcu?',
	'label_reinitialiser_compagnon' => 'Obnoviť správy zo Sprievodcu?',

	// O
	'ok' => 'OK',
	'ok_bien' => 'Dobre!',
	'ok_jai_compris' => 'Porozumel(a) som!',
	'ok_merci' => 'Ďakujem',
	'ok_parfait' => 'Dokonalé!',

	// R
	'reinitialisation' => 'Obnovenie',
	'reinitialisation_ok' => 'Vykonáva sa obnovenie.',
	'reinitialiser' => 'Obnoviť',
	'reinitialiser_moi' => 'Áno, len tie, ktoré som už prečítal(a)',
	'reinitialiser_tous' => 'Áno, nech je autor ktokoľvek',

	// T
	'titre_compagnon' => 'Sprievodca',
	'titre_page_configurer_compagnon' => 'Nastaviť Sprievodcu'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/compagnon/lang/compagnon_sk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/compagnon?lang_cible=sk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// C
	'c_accueil_bienvenue' => 'Vitajte, @nom@!',
	'c_accueil_configurer_site' => 'Nastaviť si stránku',
	'c_accueil_configurer_site_texte' => 'Jednou z prvých vecí, ktoré treba urobiť, je dať stránke názov. 
                 Momentálne má názov "@nom@". Názov stránky sa zobrazuje v hornej časti tejto stránky. 
                Kliknutím môžete zmeniť jej názov a tiež pridať logo a slogan.',
	'c_accueil_publication' => 'Publikujte!',
	'c_accueil_publication_texte' => 'Na publikovanie stránky musíte vytvoriť článok.
		Môžete to urobiť v menu "Upraviť stránku" kliknutím na "Rubriky".',
	'c_accueil_texte' => 'Práve ste sa dostali do súkromnej zóny SPIPu.',
	'c_accueil_texte_revenir' => '		Táto stránka predstavuje najnovšiu redakčnú aktivitu na vašej stránke.
		Na túto stránku sa môžete kedykoľvek vrátiť kliknutím na ikonu domčeka 
                            v hornej časti stránky pod svojím menom .',
	'c_article_redaction' => 'Článok sa upravuje',
	'c_article_redaction_redacteur' => 'Článok sa upravuje',
	'c_article_redaction_redacteur_texte' => 'Na to, aby bol váš článok odoslaný administrátorom stránky a iným redaktorom,
		v ráme na boku zmeňte stav "upravuje sa" na "odoslaný na schválenie".',
	'c_article_redaction_texte' => 'Zmeňte stav spracovania článku, aby bol jeho text publikovaný na verejne prístupnej stránke. 
		V ráme na boku zmeňte stav "upravuje sa" na "publikovaný online".',
	'c_articles_creer' => 'Vytvoriť komentár k článku?',
	'c_articles_creer_texte' => 'Vytvoriť článok môžete na tejto stránke, iba ak
		na vašej stránke existuje aspoň jedna rubrika.
		Môžete ho vytvoriť pomocou menu "Upraviť", potom "Rubriky".',
	'c_job' => 'Čo treba urobiť…',
	'c_job_texte' => 'Na tejto stránke sú uvedené nabližšie úlohy údržby,
		ktoré SPIP musí vykonať. Tieto úlohy sa vykonávajú v pravidelných intervaloch
		alebo presne na spracovanie veľkých požiadaviek zásuvných modulov,
		ako odoslanie hromadných e-mailov.',
	'c_rubrique_publier' => 'Vytvorte článok',
	'c_rubrique_publier_texte' => 'Rubrika je publikovaná, keď
		sa v nej nachádza aspoň jeden publikovaný text, napríklad publikovaný článok.
		Takže vytvorte článok. Môžete to urobiť na tejto stránke pod opisom svojej rubriky.',
	'c_rubriques_creer' => 'Vytvorte prvú rubriku!',
	'c_rubriques_creer_texte' => 'Rubriky tvoria základnú štruktúru stránky.
		V každej z nich môžete vytvárať články.
		Začnite vytvárať prvú rubriku.',
	'c_sites_creer' => 'Ako vytvoriť alebo nahrať stránku?',
	'c_sites_creer_texte' => 'Vytvoriť alebo nahrať stránku nemôžete na tejto stránke,
		kým na svojom webe nemáte rubriku.
		Tú môžete vytvoriť pomocou menu Upraviť, potom Rubriky.',

	// E
	'explication_activer_compagnon' => 'Asistent pridáva komentáre na niektoré stránky
			súkromnej zóny, aby vám pomohol s ovládaním SPIPu. Chcete ho aktivovať?',
	'explication_reinitialiser_compagnon' => 'Správy, ktoré autor videl, sa už viac nezobrazujú.			Chcete obnoviť tieto správy?',

	// L
	'label_activer_compagnon' => 'Aktivovať Sprievodcu?',
	'label_reinitialiser_compagnon' => 'Obnoviť správy zo Sprievodcu?',

	// O
	'ok' => 'OK',
	'ok_bien' => 'Dobre!',
	'ok_jai_compris' => 'Porozumel(a) som!',
	'ok_merci' => 'Ďakujem',
	'ok_parfait' => 'Dokonalé!',

	// R
	'reinitialisation' => 'Obnovenie',
	'reinitialisation_ok' => 'Vykonáva sa obnovenie.',
	'reinitialiser' => 'Obnoviť',
	'reinitialiser_moi' => 'Áno, len tie, ktoré som už prečítal(a)',
	'reinitialiser_tous' => 'Áno, nech je autor ktokoľvek',

	// T
	'titre_compagnon' => 'Sprievodca',
	'titre_page_configurer_compagnon' => 'Nastaviť Sprievodcu'
);

?>
